@@ -3,13 +3,7 @@ from .routing import respond, SchemaAPIRoute
 from .helpers import wrap_app_responses, wrap_error_responses
 
 
-__version__ = '1.2.2'
+__version__ = "1.3.0"
 
 
-__all__ = [
-    "AbstractResponseSchema",
-    "respond",
-    "SchemaAPIRoute",
-    "wrap_app_responses",
-    "wrap_error_responses"
-]
\ No newline at end of file
+__all__ = ["AbstractResponseSchema", "respond", "SchemaAPIRoute", "wrap_app_responses", "wrap_error_responses"]
